;; Copyright (C) 2015-2016 Free Software Foundation, Inc

;; Author: Rocky Bernstein <rocky@gnu.org>

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;; Python "pydb" Debugger

(eval-when-compile (require 'cl-lib))

(require 'realgud)
(require 'load-relative)

(require-relative-list '("core" "init") "realgud:pydb-")

(realgud-track-mode-vars "pydb")

(declare-function realgud-track-mode 'realgud-track-mode)
(declare-function realgud-track-mode-setup 'realgud-track-mode)
(declare-function realgud:track-set-debugger 'realgud-track-mode)
(declare-function realgud-python-populate-command-keys 'realgud-lang-python)

(realgud-python-populate-command-keys pydb-track-mode-map)

(defun pydb-track-mode-hook()
  (if pydb-track-mode
      (progn
        (use-local-map pydb-track-mode-map)
        (message "using pydb mode map")
        )
    (message "pydb track-mode-hook disable called")
    )
)

(define-minor-mode pydb-track-mode
  "Minor mode for tracking pydb source locations inside a process shell via realgud. pydb is a Python debugger.

If called interactively with no prefix argument, the mode is toggled. A prefix argument, captured as ARG, enables the mode if the argument is positive, and disables it otherwise.

\\{pydb-track-mode-map}
"
  :init-value nil
  ;; :lighter " pydb"   ;; mode-line indicator from realgud-track is sufficient.
  ;; The minor mode bindings.
  :global nil
  :group 'realgud:pydb
  :keymap pydb-track-mode-map
  (realgud:track-set-debugger "pydb")
  (if pydb-track-mode
      (progn
	(realgud-track-mode-setup 't)
        (pydb-track-mode-hook))
    (progn
      (setq realgud-track-mode nil)
      ))
)

(provide-me "realgud:pydb-")
